; The GIMP -- an image manipulation program
; Copyright (C) 1995 Spencer Kimball and Peter Mattis
; 
; Octahedron foldable maker
; Copyright (c) 2008 Justin Barca
; justinbarca@gmail.com
;
;       
; This program is free software; you can redistribute it and/or modify
; it under the terms of the GNU General Public License as published by
; the Free Software Foundation; either version 2 of the License, or
; (at your option) any later version.
; 
; This program is distributed in the hope that it will be useful,
; but WITHOUT ANY WARRANTY; without even the implied warranty of
; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
; GNU General Public License for more details.
; 
; You should have received a copy of the GNU General Public License
; along with this program; if not, write to the Free Software
; Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


(define (script-fu-octahedron-foldable image
                                 drawable                                                             
                               )
  (let* ((face01 0) (face02 0) (face03 0) (face04 0) (face05 0) (face06 0) (face07 0)  (face-rad-dist 0) (tri-rad 0) (face-length 0) (cur-ang 0) (pi 0)
       )

    (gimp-context-push)

    (gimp-image-undo-group-start image)
    (set! pi 3.14159265)
    (set! tri-rad (/ (car(gimp-image-width image)) 2))
    (set! face-rad-dist (* (cos (* (/ 60 360) 2 pi)) tri-rad))
    (set! face-length (* 2 (* (sin (* (/ 60 360) 2 pi)) tri-rad)))
  
    (gimp-image-resize image (* 4.5 face-length ) (* 5 tri-rad) (* 1.5 face-length ) 0 )

    (set! face01 (car (gimp-layer-new-from-drawable drawable image )))
    (gimp-image-add-layer image face01 -1)
    (set! cur-ang (* (/ 0 360) 2 pi) )
    (gimp-selection-none image)
    (set! face01 (car (gimp-drawable-transform-rotate-simple face01 1 1 0 0 0 )))
    (gimp-layer-translate face01 (* (sin cur-ang) 2 face-rad-dist) (* (cos cur-ang) 2 face-rad-dist))
    
    (set! face02 (car (gimp-layer-new-from-drawable face01 image)))
    (gimp-image-add-layer image face02 -1)
    (gimp-layer-translate face02 face-length 0)
    
    (set! face03 (car (gimp-layer-new-from-drawable face01 image)))
    (gimp-image-add-layer image face03 -1)
    (gimp-layer-translate face03 (* -1 face-length) 0)
    
    (set! face04 (car (gimp-layer-new-from-drawable face01 image )))
    (gimp-image-add-layer image face04 -1)
    (set! cur-ang (* (/ 60 360) 2 pi) )
    (gimp-selection-none image)
    (set! face04 (car (gimp-drawable-transform-rotate-simple face04 1 1 0 0 0 )))
    (gimp-layer-translate face04 (* (sin cur-ang) 2 face-rad-dist) (* (cos cur-ang) 2 face-rad-dist))
    
    (set! face05 (car (gimp-layer-new-from-drawable face04 image)))
    (gimp-image-add-layer image face05 -1)
    (gimp-layer-translate face05 face-length 0)
    
    (set! face06 (car (gimp-layer-new-from-drawable face04 image)))
    (gimp-image-add-layer image face06 -1)
    (gimp-layer-translate face06 (* -1 face-length) 0)
    
    (set! face07 (car (gimp-layer-new-from-drawable face04 image )))
    (gimp-image-add-layer image face07 -1)
    (set! cur-ang (* (/ 0 360) 2 pi) )
    (gimp-selection-none image)
    (set! face07 (car (gimp-drawable-transform-rotate-simple face07 1 1 0 0 0 )))
    (gimp-layer-translate face07 (* (sin cur-ang) 2 face-rad-dist) (* (cos cur-ang) 2 face-rad-dist))
    
    (set! drawable (car (gimp-image-merge-visible-layers image 1)))
    (plug-in-autocrop 1 image drawable)
    
  
    (gimp-image-undo-group-end image)
    (gimp-displays-flush)

    (gimp-context-pop)
  )
)

(script-fu-register "script-fu-octahedron-foldable"
  _"_Octahedron"
  _"Make a shape that can be folded into a octahedron with images of current layer as faces"
  "Justin Barca <justinbarca@gmail.com>"
  "Justin Barca"
  "2008/03/13"
  "RGB* GRAY*"
  SF-IMAGE      "Image"           0
  SF-DRAWABLE   "Drawable"        0
  
)

(script-fu-menu-register "script-fu-octahedron-foldable"
                         "<Image>/Filters/Render/Foldables")
